Data Classes and Check Registration
===================================

All common data class used across the package, as well as the decorator for adding a check function to the registry.

.. automodule:: nwbinspector._types

.. automodule:: nwbinspector._registration
